@@ -121,7 +121,7 @@ class ModelRepository:
             conn = self.conpool.getconn()
             cur = conn.cursor()
             script_content = psycopg2.Binary(python_script_content)
-            cur.execute(f"INSERT INTO io_fintix.custom_model (model_uid, model_name, model) VALUES({model_name}, {model_name}, %s) ON CONFLICT (model_uid) DO UPDATE SET model = %s WHERE model_uid = '{model_name}'",
+            cur.execute(f"INSERT INTO io_fintix.custom_model (model_uid, model_name, model) VALUES('{model_name}', '{model_name}', %s) ON CONFLICT (model_uid) DO UPDATE SET model = %s",
                         (script_content, script_content))
             conn.commit()
             logging.info(f"Successfully upload converted python script of model '{model_name}' notebook into database")
