@@ -1,4 +1,5 @@
 import json
+from fintix_modelcurator.const import *
 
 
 class Settings:
@@ -8,7 +9,8 @@ class Settings:
         self.settings = None
 
     def init(self, setting_strings):
-        self.settings = json.load(setting_strings)
+        self.settings = json.loads(setting_strings)
+        return NoResult, NoError
 
     def get_settings(self):
         return self.settings
